BarcodeCountIcon class

Constructors

BarcodeCountIcon({ScanditIcon? defaultIcon, ScanditIcon? accessibleIcon})
BarcodeCountIcon.fromJSON(Map<String, dynamic> json)
factory

Properties

accessibleIcon → ScanditIcon?
final
defaultIcon → ScanditIcon?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited