BarcodeSelection class

Properties

context → DataCaptureContext?
no setter
feedback ↔ BarcodeSelectionFeedback
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isEnabled ↔ bool
getter/setter pair
pointOfInterest ↔ PointWithUnit?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(BarcodeSelectionListener listener) → void
applySettings(BarcodeSelectionSettings settings) → Future<void>
freezeCamera() → Future<void>
getBarcodeSelectionLicenseInfo() → Future<BarcodeSelectionLicenseInfo?>
increaseCountForBarcodes(List<Barcode> barcodes) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(BarcodeSelectionListener listener) → void
reset() → Future<void>
selectAimedBarcode() → Future<void>
selectUnselectedBarcodes() → Future<void>
setSelectBarcodeEnabled(Barcode barcode, bool enabled) → Future<void>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
unfreezeCamera() → Future<void>
unselectBarcodes(List<Barcode> barcodes) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createRecommendedCameraSettings() → CameraSettings