BarcodeSelectionBasicOverlay class

Properties

aimedBrush ↔ Brush
getter/setter pair
frozenBackgroundColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBrush ↔ Brush
getter/setter pair
selectingBrush ↔ Brush
getter/setter pair
shouldShowHints ↔ bool
getter/setter pair
shouldShowScanAreaGuides ↔ bool
getter/setter pair
style → BarcodeSelectionBasicOverlayStyle
final
trackedBrush ↔ Brush
getter/setter pair
view ↔ DataCaptureView?
getter/setter pair
viewfinder → Viewfinder
no setter

Methods

clearSelectedBarcodeBrushes() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAimedBarcodeBrushProvider(BarcodeSelectionBrushProvider? brushProvider) → Future<void>
setTextForAimToSelectAutoHint(String text) → Future<void>
setTextForDoubleTapToUnfreezeHint(String text) → Future<void>
setTextForSelectOrDoubleTapToFreezeHint(String text) → Future<void>
setTextForTapAnywhereToSelectHint(String text) → Future<void>
setTextForTapToSelectHint(String text) → Future<void>
setTrackedBarcodeBrushProvider(BarcodeSelectionBrushProvider? brushProvider) → Future<void>
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited