BarcodeSelectionSession class

Constructors

BarcodeSelectionSession.fromJSON(Map<String, dynamic> event)
factory

Properties

frameId → String?
no setterinherited
frameSequenceId → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
newlySelectedBarcodes → List<Barcode>
no setter
newlyUnselectedBarcodes → List<Barcode>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBarcodes → List<Barcode>
no setter

Methods

getCount(Barcode barcode) → Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → Future<void>
selectUnselectedBarcodes() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited